==> dapware-gateway-2.7.19.18-sources.jar: com/digiwin/dap/middle/gateway/HttpStatsConfiguration.java <==
package com.digiwin.dap.middle.gateway;

import com.digiwin.dap.middle.gateway.constant.GatewayConstants;
import com.digiwin.dap.middle.gateway.service.stats.filter.HttpStatsFilter;
import com.digiwin.dap.middle.gateway.service.stats.interceptor.HttpStatsInterceptor;
import com.digiwin.dap.middleware.domain.DapEnv;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.web.servlet.handler.MappedInterceptor;

import javax.servlet.Filter;

@AutoConfiguration
@ConditionalOnProperty(name = "dap.middleware.stats-api", havingValue = "true")
public class HttpStatsConfiguration {

    @Autowired
    private DapEnv dapEnv;

    @Bean
    @ConditionalOnProperty(name = "spring.redis.host")
    @ConditionalOnMissingBean(name = "httpStatsFilter")
    public FilterRegistrationBean<Filter> httpStatsFilter() {
        FilterRegistrationBean<Filter> registrationBean = new FilterRegistrationBean<>();
        final HttpStatsFilter filter = new HttpStatsFilter(dapEnv.getAppName());
        registrationBean.setFilter(filter);
        registrationBean.setOrder(filter.getOrder());
        registrationBean.addUrlPatterns(GatewayConstants.DEFAULT_URL_MAPPINGS);
        return registrationBean;
    }

    @Bean
    @ConditionalOnMissingBean(name = "httpStatsInterceptor")
    public MappedInterceptor httpStatsInterceptor() {
        HttpStatsInterceptor interceptor = new HttpStatsInterceptor();
        return new MappedInterceptor(GatewayConstants.DEFAULT_PATH_MAPPINGS, interceptor);
    }
}

==> dapware-gateway-3.5.0-20251205.012718-15-sources.jar: com/digiwin/dap/middle/gateway/HttpStatsConfiguration.java <==
package com.digiwin.dap.middle.gateway;

import com.digiwin.dap.middle.gateway.constant.GatewayConstants;
import com.digiwin.dap.middle.gateway.service.stats.filter.HttpStatsFilter;
import com.digiwin.dap.middle.gateway.service.stats.interceptor.HttpStatsInterceptor;
import com.digiwin.dap.middleware.domain.DapEnv;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.web.servlet.handler.MappedInterceptor;

import jakarta.servlet.Filter;

@AutoConfiguration
@ConditionalOnProperty(name = "dap.middleware.stats-api", havingValue = "true")
public class HttpStatsConfiguration {

    @Autowired
    private DapEnv dapEnv;

    @Bean
    @ConditionalOnProperty(name = "spring.redis.host")
    @ConditionalOnMissingBean(name = "httpStatsFilter")
    public FilterRegistrationBean<Filter> httpStatsFilter() {
        FilterRegistrationBean<Filter> registrationBean = new FilterRegistrationBean<>();
        final HttpStatsFilter filter = new HttpStatsFilter(dapEnv.getAppName());
        registrationBean.setFilter(filter);
        registrationBean.setOrder(filter.getOrder());
        registrationBean.addUrlPatterns(GatewayConstants.DEFAULT_URL_MAPPINGS);
        return registrationBean;
    }

    @Bean
    @ConditionalOnMissingBean(name = "httpStatsInterceptor")
    public MappedInterceptor httpStatsInterceptor() {
        HttpStatsInterceptor interceptor = new HttpStatsInterceptor();
        return new MappedInterceptor(GatewayConstants.DEFAULT_PATH_MAPPINGS, interceptor);
    }
}
